@@ -12,6 +12,6 @@ This is the complete API reference:
    hub
 """
 
-__version__ = "0.5.0"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.5.2"  # denote a pre-release for 0.1.0 with 0.1a1
 
-from ._hub import hub  # noqa
+from ._hub import get_hub_with_authentication, hub  # noqa
