@@ -15,6 +15,10 @@ def lint(session: nox.Session) -> None:
 @nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11"])
 def build(session):
     session.install(".[dev,test]")
+    login_user_1 = "lndb login raspbear@gmx.de --password MmR4YuQEyb0yxu7dAwJZTjLzR1Az2lN4Q4IduDlO"  # noqa
+    create_instance_1 = "lndb init --storage mydata --schema bionty,wetlab"  # noqa
+    session.run(*(login_user_1.split(" ")))
+    session.run(*(create_instance_1.split(" ")))
     session.run(
         "pytest",
         "-s",
@@ -26,3 +30,10 @@ def build(session):
     prefix = "." if Path("./lndocs").exists() else ".."
     session.install(f"{prefix}/lndocs")
     session.run("lndocs")
+    session.run(
+        "pytest",
+        "-s",
+        "--cov=lndb_hub",
+        "--cov-append",
+        "--cov-report=term-missing",
+    )
